@@ -7,12 +7,14 @@ from typing import (
     Iterable,
     List,
     Mapping,
+    TYPE_CHECKING,
+    cast,
 )
 
 from debputy.filesystem_scan import VirtualPathBase
 from debputy.linting.lint_util import LintState
 from debputy.lsp.debputy_ls import DebputyLanguageServer
-from debputy.lsp.diagnostics import DiagnosticData
+from debputy.lsp.diagnostics import DiagnosticData, LintSeverity
 from debputy.lsp.lsp_features import (
     lint_diagnostics,
     lsp_standard_handler,
@@ -39,12 +41,15 @@ from debputy.lsprotocol.types import (
     SemanticTokens,
     SemanticTokenTypes,
     Position,
-    Range,
-    DiagnosticSeverity,
     CompletionItemKind,
     CompletionItemLabelDetails,
 )
 
+if TYPE_CHECKING:
+    import lsprotocol.types as types
+else:
+    import debputy.lsprotocol.types as types
+
 try:
     from debputy.lsp.vendoring._deb822_repro.locatable import (
         Position as TEPosition,
@@ -67,15 +72,7 @@ _DISPATCH_RULE = LanguageDispatchRule.new_rule(
 )
 
 
-def _as_hook_targets(command_name: str) -> Iterable[str]:
-    for prefix, suffix in itertools.product(
-        ["override_", "execute_before_", "execute_after_"],
-        ["", "-arch", "-indep"],
-    ):
-        yield f"{prefix}{command_name}{suffix}"
-
-
-# lsp_standard_handler(_DISPATCH_RULE, TEXT_DOCUMENT_CODE_ACTION)
+lsp_standard_handler(_DISPATCH_RULE, types.TEXT_DOCUMENT_CODE_ACTION)
 lsp_standard_handler(_DISPATCH_RULE, TEXT_DOCUMENT_WILL_SAVE_WAIT_UNTIL)
 
 _RE_LINE_COMMENT = re.compile(r"^\s*(#(?:.*\S)?)\s*$")
@@ -91,10 +88,6 @@ _RE_UNNECESSARY_LEADING_PREFIX = re.compile(r"(?:(?:[.]{1,2})?/+)+")
 _RE_UNNECESSARY_SLASHES = re.compile("//+")
 
 
-def is_valid_file(path: str) -> bool:
-    return path.endswith("/patches/series")
-
-
 def _all_patch_files(
     debian_patches: VirtualPathBase,
 ) -> Iterable[VirtualPathBase]:
@@ -140,10 +133,7 @@ def _listed_patches(
 
 
 @lint_diagnostics(_DISPATCH_RULE)
-def _lint_debian_patches_series(lint_state: LintState) -> Optional[List[Diagnostic]]:
-    if not is_valid_file(lint_state.path):
-        return None
-
+def _lint_debian_patches_series(lint_state: LintState) -> None:
     source_root = lint_state.source_root
     if source_root is None:
         return None
@@ -152,8 +142,6 @@ def _lint_debian_patches_series(lint_state: LintState) -> Optional[List[Diagnost
     if dpatches is None or not dpatches.is_dir:
         return None
 
-    position_codec = lint_state.position_codec
-    diagnostics = []
     used_patches = set()
     all_patches = {pf.path for pf in _all_patch_files(dpatches)}
 
@@ -175,116 +163,90 @@ def _lint_debian_patches_series(lint_state: LintState) -> Optional[List[Diagnost
             orig_filename_start_col = slash_end
             prefix = filename[:orig_filename_start_col]
             filename = filename[orig_filename_start_col:]
-            slash_range = position_codec.range_to_client_units(
-                lint_state.lines,
-                Range(
-                    Position(
-                        line_no,
-                        patch_start_col + slash_start,
-                    ),
-                    Position(
-                        line_no,
-                        patch_start_col + slash_end,
-                    ),
+            slash_range = TERange(
+                TEPosition(
+                    line_no,
+                    patch_start_col + slash_start,
+                ),
+                TEPosition(
+                    line_no,
+                    patch_start_col + slash_end,
                 ),
             )
             skip_use_check = False
             if ".." in prefix:
                 diagnostic_title = f'Disallowed prefix "{prefix}"'
-                severity = DiagnosticSeverity.Error
+                severity = cast("LintSeverity", "error")
                 skip_use_check = True
             else:
                 diagnostic_title = f'Unnecessary prefix "{prefix}"'
-                severity = DiagnosticSeverity.Warning
-            diagnostics.append(
-                Diagnostic(
-                    slash_range,
-                    diagnostic_title,
-                    source="debputy",
-                    severity=severity,
-                    data=DiagnosticData(
-                        quickfixes=[
-                            propose_remove_range_quick_fix(
-                                proposed_title=f'Remove prefix "{prefix}"'
-                            )
-                        ]
-                    ),
-                )
+                severity = cast("LintSeverity", "warning")
+            lint_state.emit_diagnostic(
+                slash_range,
+                diagnostic_title,
+                severity,
+                "debputy",
+                quickfixes=[
+                    propose_remove_range_quick_fix(
+                        proposed_title=f'Remove prefix "{prefix}"'
+                    )
+                ],
             )
             if skip_use_check:
                 continue
         if "//" in filename:
             for usm in _RE_UNNECESSARY_SLASHES.finditer(filename):
                 start_col, end_cold = usm.span()
-                slash_range = position_codec.range_to_client_units(
-                    lint_state.lines,
-                    Range(
-                        Position(
-                            line_no,
-                            orig_filename_start_col + start_col,
-                        ),
-                        Position(
-                            line_no,
-                            orig_filename_start_col + end_cold,
-                        ),
+                slash_range = TERange(
+                    TEPosition(
+                        line_no,
+                        orig_filename_start_col + start_col,
+                    ),
+                    TEPosition(
+                        line_no,
+                        orig_filename_start_col + end_cold,
                     ),
                 )
-                diagnostics.append(
-                    Diagnostic(
-                        slash_range,
-                        "Unnecessary slashes",
-                        source="debputy",
-                        severity=DiagnosticSeverity.Warning,
-                        data=DiagnosticData(
-                            quickfixes=[propose_correct_text_quick_fix("/")]
-                        ),
-                    )
+                lint_state.emit_diagnostic(
+                    slash_range,
+                    "Unnecessary slashes",
+                    "warning",
+                    "debputy",
+                    quickfixes=[propose_correct_text_quick_fix("/")],
                 )
             filename = _RE_UNNECESSARY_SLASHES.sub("/", filename)
 
-        patch_name_range = position_codec.range_to_client_units(
-            lint_state.lines,
-            Range(
-                Position(
-                    line_no,
-                    patch_start_col,
-                ),
-                Position(
-                    line_no,
-                    patch_end_col,
-                ),
+        patch_name_range = TERange(
+            TEPosition(
+                line_no,
+                patch_start_col,
+            ),
+            TEPosition(
+                line_no,
+                patch_end_col,
             ),
         )
         if not filename.lower().endswith((".diff", ".patch")):
-            diagnostics.append(
-                Diagnostic(
-                    patch_name_range,
-                    f'Patch not using ".patch" or ".diff" as extension: "{filename}"',
-                    source="debputy",
-                    severity=DiagnosticSeverity.Hint,
-                    data=DiagnosticData(
-                        quickfixes=[propose_correct_text_quick_fix(f"{filename}.patch")]
-                    ),
-                )
+            lint_state.emit_diagnostic(
+                patch_name_range,
+                f'Patch not using ".patch" or ".diff" as extension: "{filename}"',
+                "pedantic",
+                "debputy",
             )
         patch_path = f"{dpatches.path}/{filename}"
         if patch_path not in all_patches:
-            diagnostics.append(
-                Diagnostic(
-                    patch_name_range,
-                    f'Non-existing patch "{filename}"',
-                    source="debputy",
-                    severity=DiagnosticSeverity.Error,
-                )
+            lint_state.emit_diagnostic(
+                patch_name_range,
+                f'Non-existing patch "{filename}"',
+                "error",
+                "debputy",
             )
         elif patch_path in used_patches:
-            diagnostics.append(
-                Diagnostic(
-                    patch_name_range,
-                    f'Duplicate patch: "{filename}"',
-                    source="debputy",
-                    severity=DiagnosticSeverity.Error,
-                )
+            lint_state.emit_diagnostic(
+                patch_name_range,
+                f'Duplicate patch: "{filename}"',
+                "error",
+                "debputy",
             )
         else:
             used_patches.add(patch_path)
@@ -293,27 +255,23 @@ def _lint_debian_patches_series(lint_state: LintState) -> Optional[List[Diagnost
     for unused_patch in sorted(unused_patches):
         patch_name = unused_patch[len(dpatches.path) + 1 :]
         line_count = len(lint_state.lines)
-        file_range = Range(
-            Position(
+        file_range = TERange(
+            TEPosition(
                 0,
                 0,
             ),
-            Position(
+            TEPosition(
                 line_count,
                 len(lint_state.lines[-1]) if line_count else 0,
             ),
         )
-        diagnostics.append(
-            Diagnostic(
-                file_range,
-                f'Unused patch: "{patch_name}"',
-                source="debputy",
-                severity=DiagnosticSeverity.Warning,
-            )
+        lint_state.emit_diagnostic(
+            file_range,
+            f'Unused patch: "{patch_name}"',
+            "warning",
+            "debputy",
         )
 
-    return diagnostics
-
 
 @lsp_completer(_DISPATCH_RULE)
 def _debian_patches_series_completions(
@@ -321,8 +279,6 @@ def _debian_patches_series_completions(
     params: CompletionParams,
 ) -> Optional[Union[CompletionList, Sequence[CompletionItem]]]:
     doc = ls.workspace.get_text_document(params.text_document.uri)
-    if not is_valid_file(doc.path):
-        return None
     lint_state = ls.lint_state(doc)
     source_root = lint_state.source_root
     dpatches = source_root.lookup("debian/patches") if source_root is not None else None
@@ -364,8 +320,6 @@ def _debian_patches_semantic_tokens_full(
     request: SemanticTokensParams,
 ) -> Optional[SemanticTokens]:
     doc = ls.workspace.get_text_document(request.text_document.uri)
-    if not is_valid_file(doc.path):
-        return None
     lines = doc.lines
     position_codec = doc.position_codec
 
