@@ -45,6 +45,8 @@ except ImportError:
     def detect_possible_typo(
         provided_value: str,
         known_values: Iterable[str],
+        *,
+        max_edit_distance: int = 2,
     ) -> Sequence[str]:
         return ()
 
@@ -55,14 +57,16 @@ else:
     def detect_possible_typo(
         provided_value: str,
         known_values: Iterable[str],
+        *,
+        max_edit_distance: int = 2,
     ) -> Sequence[str]:
         k_len = len(provided_value)
         candidates = []
         for known_value in known_values:
-            if abs(k_len - len(known_value)) > 2:
+            if abs(k_len - len(known_value)) > max_edit_distance:
                 continue
             d = distance(provided_value, known_value)
-            if d > 2:
+            if d > max_edit_distance:
                 continue
             candidates.append(known_value)
         return candidates
@@ -99,8 +103,9 @@ POSTINST_DEFAULT_CONDITION = (
 
 
 _SPACE_RE = re.compile(r"\s")
+_WORD_EQUAL = re.compile(r"^-*[\w_\-]+=")
 _DOUBLE_ESCAPEES = re.compile(r'([\n`$"\\])')
-_REGULAR_ESCAPEES = re.compile(r'([\s!"$()*+#;<>?@\[\]\\`|~])')
+_REGULAR_ESCAPEES = re.compile(r"""([\s!"$()*+#;<>?@'\[\]\\`|~])""")
 _PROFILE_GROUP_SPLIT = re.compile(r">\s+<")
 _DEFAULT_LOGGER: Optional[logging.Logger] = None
 _STDOUT_HANDLER: Optional[logging.StreamHandler[Any]] = None
@@ -242,7 +247,13 @@ def _backslash_escape(m: re.Match[str]) -> str:
 
 
 def _escape_shell_word(w: str) -> str:
-    if _SPACE_RE.match(w):
+    if _SPACE_RE.search(w):
+        if "=" in w and (m := _WORD_EQUAL.search(w)) is not None:
+            s = m.span(0)
+            assert s[0] == 0
+            prefix = w[0 : s[1]]
+            escaped_value = _DOUBLE_ESCAPEES.sub(_backslash_escape, w[s[1] :])
+            return f'{prefix}"{escaped_value}"'
         w = _DOUBLE_ESCAPEES.sub(_backslash_escape, w)
         return f'"{w}"'
     return _REGULAR_ESCAPEES.sub(_backslash_escape, w)
@@ -562,7 +573,7 @@ def generated_content_dir(
 
 
 PerlConfigVars = collections.namedtuple(
-    "PerlIncDir", ["vendorlib", "vendorarch", "cross_inc_dir", "ld", "path_sep"]
+    "PerlConfigVars", ["vendorlib", "vendorarch", "cross_inc_dir", "ld", "path_sep"]
 )
 PerlConfigData = collections.namedtuple("PerlConfigData", ["version", "debian_abi"])
 _PERL_MODULE_DIRS: Dict[str, PerlConfigVars] = {}
@@ -604,21 +615,22 @@ def resolve_perl_config(
 ) -> PerlConfigVars:
     global _PERL_MODULE_DIRS
     if dpkg_architecture_variables.is_cross_compiling:
-        arch = (
-            dctrl_bin.resolved_architecture
-            if dctrl_bin is not None
-            else dpkg_architecture_variables.current_host_arch
-        )
+        if dctrl_bin is not None:
+            arch = dctrl_bin.resolved_architecture
+            ma = dctrl_bin.deb_multiarch
+        else:
+            arch = dpkg_architecture_variables.current_host_arch
+            ma = dpkg_architecture_variables.current_host_multiarch
     else:
+        # We are de facto using the build-arch version of perl here; be explicit
         arch = "_build_arch_"
+        ma = dpkg_architecture_variables["DEB_BUILD_MULTIARCH"]
     config_vars = _PERL_MODULE_DIRS.get(arch)
     if config_vars is None:
         cmd = ["perl"]
         if dpkg_architecture_variables.is_cross_compiling:
             version = _perl_version()
-            cross_inc_dir = (
-                f"/usr/lib/{dctrl_bin.deb_multiarch}/perl/cross-config-{version}"
-            )
+            cross_inc_dir = f"/usr/lib/{ma}/perl/cross-config-{version}"
             # FIXME: This should not fallback to "build-arch" but on the other hand, we use the perl module dirs
             #  for every package at the moment. So mandating correct perl dirs implies mandating perl-xs-dev in
             #  cross builds... meh.
@@ -856,6 +868,7 @@ def change_log_level(
 ) -> None:
     if _DEFAULT_LOGGER is not None:
         _DEFAULT_LOGGER.setLevel(log_level)
+    logging.getLogger("").setLevel(log_level)
 
 
 def current_log_level() -> Optional[int]:
