@@ -26,7 +26,6 @@ try:
 except ImportError:
     HAS_LEVENSHTEIN = False
 
-
 LINTER_POSITION_CODEC = LinterPositionCodec()
 
 
@@ -71,8 +70,9 @@ class LintWrapper:
             source_package,
             binary_packages,
             self.effective_preference,
+            self._handler,
         )
-        return check_diagnostics(self._handler(state))
+        return check_diagnostics(state.gather_diagnostics())
 
 
 def requires_levenshtein(func: Any) -> Any:
